@@ -15,7 +15,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-# pylint: disable=too-many-lines
+# pylint: disable=too-many-lines,broad-exception-raised
 """Functional tests of minio-py."""
 
 from __future__ import absolute_import, division
@@ -1090,7 +1090,7 @@ def _test_list_objects(log_entry, use_api_v1=False, version_check=False):
                 raise ValueError(
                     f"version ID mismatch. "
                     f"expected=any{[version_id1, version_id2]}, "
-                    f"got:{obj.verion_id}"
+                    f"got:{obj.version_id}"
                 )
     finally:
         _CLIENT.remove_object(
